Page MenuHomePhabricator

D9999.diff
No OneTemporary

D9999.diff

diff --git a/src/__phutil_library_map__.php b/src/__phutil_library_map__.php
--- a/src/__phutil_library_map__.php
+++ b/src/__phutil_library_map__.php
@@ -1127,6 +1127,7 @@
'PhabricatorActionListView' => 'view/layout/PhabricatorActionListView.php',
'PhabricatorActionView' => 'view/layout/PhabricatorActionView.php',
'PhabricatorAllCapsTranslation' => 'infrastructure/internationalization/translation/PhabricatorAllCapsTranslation.php',
+ 'PhabricatorAmazonAuthProvider' => 'applications/auth/provider/PhabricatorAmazonAuthProvider.php',
'PhabricatorAnchorView' => 'view/layout/PhabricatorAnchorView.php',
'PhabricatorAphlictManagementBuildWorkflow' => 'applications/aphlict/management/PhabricatorAphlictManagementBuildWorkflow.php',
'PhabricatorAphlictManagementDebugWorkflow' => 'applications/aphlict/management/PhabricatorAphlictManagementDebugWorkflow.php',
@@ -1240,6 +1241,7 @@
'PhabricatorApplicationXHProf' => 'applications/xhprof/application/PhabricatorApplicationXHProf.php',
'PhabricatorApplicationsController' => 'applications/meta/controller/PhabricatorApplicationsController.php',
'PhabricatorApplicationsListController' => 'applications/meta/controller/PhabricatorApplicationsListController.php',
+ 'PhabricatorAsanaAuthProvider' => 'applications/auth/provider/PhabricatorAsanaAuthProvider.php',
'PhabricatorAsanaConfigOptions' => 'applications/doorkeeper/option/PhabricatorAsanaConfigOptions.php',
'PhabricatorAuditActionConstants' => 'applications/audit/constants/PhabricatorAuditActionConstants.php',
'PhabricatorAuditAddCommentController' => 'applications/audit/controller/PhabricatorAuditAddCommentController.php',
@@ -1293,23 +1295,6 @@
'PhabricatorAuthProviderConfigQuery' => 'applications/auth/query/PhabricatorAuthProviderConfigQuery.php',
'PhabricatorAuthProviderConfigTransaction' => 'applications/auth/storage/PhabricatorAuthProviderConfigTransaction.php',
'PhabricatorAuthProviderConfigTransactionQuery' => 'applications/auth/query/PhabricatorAuthProviderConfigTransactionQuery.php',
- 'PhabricatorAuthProviderLDAP' => 'applications/auth/provider/PhabricatorAuthProviderLDAP.php',
- 'PhabricatorAuthProviderOAuth' => 'applications/auth/provider/PhabricatorAuthProviderOAuth.php',
- 'PhabricatorAuthProviderOAuth1' => 'applications/auth/provider/PhabricatorAuthProviderOAuth1.php',
- 'PhabricatorAuthProviderOAuth1Bitbucket' => 'applications/auth/provider/PhabricatorAuthProviderOAuth1Bitbucket.php',
- 'PhabricatorAuthProviderOAuth1JIRA' => 'applications/auth/provider/PhabricatorAuthProviderOAuth1JIRA.php',
- 'PhabricatorAuthProviderOAuth1Twitter' => 'applications/auth/provider/PhabricatorAuthProviderOAuth1Twitter.php',
- 'PhabricatorAuthProviderOAuth2' => 'applications/auth/provider/PhabricatorAuthProviderOAuth2.php',
- 'PhabricatorAuthProviderOAuthAmazon' => 'applications/auth/provider/PhabricatorAuthProviderOAuthAmazon.php',
- 'PhabricatorAuthProviderOAuthAsana' => 'applications/auth/provider/PhabricatorAuthProviderOAuthAsana.php',
- 'PhabricatorAuthProviderOAuthDisqus' => 'applications/auth/provider/PhabricatorAuthProviderOAuthDisqus.php',
- 'PhabricatorAuthProviderOAuthFacebook' => 'applications/auth/provider/PhabricatorAuthProviderOAuthFacebook.php',
- 'PhabricatorAuthProviderOAuthGitHub' => 'applications/auth/provider/PhabricatorAuthProviderOAuthGitHub.php',
- 'PhabricatorAuthProviderOAuthGoogle' => 'applications/auth/provider/PhabricatorAuthProviderOAuthGoogle.php',
- 'PhabricatorAuthProviderOAuthTwitch' => 'applications/auth/provider/PhabricatorAuthProviderOAuthTwitch.php',
- 'PhabricatorAuthProviderOAuthWordPress' => 'applications/auth/provider/PhabricatorAuthProviderOAuthWordPress.php',
- 'PhabricatorAuthProviderPassword' => 'applications/auth/provider/PhabricatorAuthProviderPassword.php',
- 'PhabricatorAuthProviderPersona' => 'applications/auth/provider/PhabricatorAuthProviderPersona.php',
'PhabricatorAuthRegisterController' => 'applications/auth/controller/PhabricatorAuthRegisterController.php',
'PhabricatorAuthSession' => 'applications/auth/storage/PhabricatorAuthSession.php',
'PhabricatorAuthSessionEngine' => 'applications/auth/engine/PhabricatorAuthSessionEngine.php',
@@ -1330,6 +1315,7 @@
'PhabricatorBaseEnglishTranslation' => 'infrastructure/internationalization/translation/PhabricatorBaseEnglishTranslation.php',
'PhabricatorBaseProtocolAdapter' => 'infrastructure/daemon/bot/adapter/PhabricatorBaseProtocolAdapter.php',
'PhabricatorBcryptPasswordHasher' => 'infrastructure/util/password/PhabricatorBcryptPasswordHasher.php',
+ 'PhabricatorBitbucketAuthProvider' => 'applications/auth/provider/PhabricatorBitbucketAuthProvider.php',
'PhabricatorBot' => 'infrastructure/daemon/bot/PhabricatorBot.php',
'PhabricatorBotBaseStreamingProtocolAdapter' => 'infrastructure/daemon/bot/adapter/PhabricatorBotBaseStreamingProtocolAdapter.php',
'PhabricatorBotChannel' => 'infrastructure/daemon/bot/target/PhabricatorBotChannel.php',
@@ -1557,6 +1543,7 @@
'PhabricatorDifferentialRevisionTestDataGenerator' => 'applications/differential/lipsum/PhabricatorDifferentialRevisionTestDataGenerator.php',
'PhabricatorDiffusionConfigOptions' => 'applications/diffusion/config/PhabricatorDiffusionConfigOptions.php',
'PhabricatorDisabledUserController' => 'applications/auth/controller/PhabricatorDisabledUserController.php',
+ 'PhabricatorDisqusAuthProvider' => 'applications/auth/provider/PhabricatorDisqusAuthProvider.php',
'PhabricatorDisqusConfigOptions' => 'applications/config/option/PhabricatorDisqusConfigOptions.php',
'PhabricatorDraft' => 'applications/draft/storage/PhabricatorDraft.php',
'PhabricatorDraftDAO' => 'applications/draft/storage/PhabricatorDraftDAO.php',
@@ -1584,6 +1571,7 @@
'PhabricatorExtendingPhabricatorConfigOptions' => 'applications/config/option/PhabricatorExtendingPhabricatorConfigOptions.php',
'PhabricatorExternalAccount' => 'applications/people/storage/PhabricatorExternalAccount.php',
'PhabricatorExternalAccountQuery' => 'applications/auth/query/PhabricatorExternalAccountQuery.php',
+ 'PhabricatorFacebookAuthProvider' => 'applications/auth/provider/PhabricatorFacebookAuthProvider.php',
'PhabricatorFactAggregate' => 'applications/fact/storage/PhabricatorFactAggregate.php',
'PhabricatorFactChartController' => 'applications/fact/controller/PhabricatorFactChartController.php',
'PhabricatorFactController' => 'applications/fact/controller/PhabricatorFactController.php',
@@ -1688,8 +1676,10 @@
'PhabricatorGarbageCollectorDaemon' => 'infrastructure/daemon/garbagecollector/PhabricatorGarbageCollectorDaemon.php',
'PhabricatorGestureExample' => 'applications/uiexample/examples/PhabricatorGestureExample.php',
'PhabricatorGitGraphStream' => 'applications/repository/daemon/PhabricatorGitGraphStream.php',
+ 'PhabricatorGitHubAuthProvider' => 'applications/auth/provider/PhabricatorGitHubAuthProvider.php',
'PhabricatorGlobalLock' => 'infrastructure/util/PhabricatorGlobalLock.php',
'PhabricatorGlobalUploadTargetView' => 'applications/files/view/PhabricatorGlobalUploadTargetView.php',
+ 'PhabricatorGoogleAuthProvider' => 'applications/auth/provider/PhabricatorGoogleAuthProvider.php',
'PhabricatorHandleObjectSelectorDataView' => 'applications/phid/handle/view/PhabricatorHandleObjectSelectorDataView.php',
'PhabricatorHandleQuery' => 'applications/phid/query/PhabricatorHandleQuery.php',
'PhabricatorHarbormasterConfigOptions' => 'applications/harbormaster/config/PhabricatorHarbormasterConfigOptions.php',
@@ -1715,9 +1705,11 @@
'PhabricatorInternationalizationManagementExtractWorkflow' => 'infrastructure/internationalization/management/PhabricatorInternationalizationManagementExtractWorkflow.php',
'PhabricatorInternationalizationManagementWorkflow' => 'infrastructure/internationalization/management/PhabricatorInternationalizationManagementWorkflow.php',
'PhabricatorIteratedMD5PasswordHasher' => 'infrastructure/util/password/PhabricatorIteratedMD5PasswordHasher.php',
+ 'PhabricatorJIRAAuthProvider' => 'applications/auth/provider/PhabricatorJIRAAuthProvider.php',
'PhabricatorJavelinLinter' => 'infrastructure/lint/linter/PhabricatorJavelinLinter.php',
'PhabricatorJumpNavHandler' => 'applications/search/engine/PhabricatorJumpNavHandler.php',
'PhabricatorKeyValueDatabaseCache' => 'applications/cache/PhabricatorKeyValueDatabaseCache.php',
+ 'PhabricatorLDAPAuthProvider' => 'applications/auth/provider/PhabricatorLDAPAuthProvider.php',
'PhabricatorLegacyEdgeType' => 'infrastructure/edges/type/PhabricatorLegacyEdgeType.php',
'PhabricatorLegalpadConfigOptions' => 'applications/legalpad/config/PhabricatorLegalpadConfigOptions.php',
'PhabricatorLegalpadPHIDTypeDocument' => 'applications/legalpad/phid/PhabricatorLegalpadPHIDTypeDocument.php',
@@ -1833,6 +1825,9 @@
'PhabricatorNotificationStatusController' => 'applications/notification/controller/PhabricatorNotificationStatusController.php',
'PhabricatorNotificationStatusView' => 'applications/notification/view/PhabricatorNotificationStatusView.php',
'PhabricatorNotificationTestController' => 'applications/notification/controller/PhabricatorNotificationTestController.php',
+ 'PhabricatorOAuth1AuthProvider' => 'applications/auth/provider/PhabricatorOAuth1AuthProvider.php',
+ 'PhabricatorOAuth2AuthProvider' => 'applications/auth/provider/PhabricatorOAuth2AuthProvider.php',
+ 'PhabricatorOAuthAuthProvider' => 'applications/auth/provider/PhabricatorOAuthAuthProvider.php',
'PhabricatorOAuthClientAuthorization' => 'applications/oauthserver/storage/PhabricatorOAuthClientAuthorization.php',
'PhabricatorOAuthClientAuthorizationQuery' => 'applications/oauthserver/query/PhabricatorOAuthClientAuthorizationQuery.php',
'PhabricatorOAuthClientController' => 'applications/oauthserver/controller/client/PhabricatorOAuthClientController.php',
@@ -1891,6 +1886,7 @@
'PhabricatorPHIDType' => 'applications/phid/type/PhabricatorPHIDType.php',
'PhabricatorPHPMailerConfigOptions' => 'applications/config/option/PhabricatorPHPMailerConfigOptions.php',
'PhabricatorPagedFormExample' => 'applications/uiexample/examples/PhabricatorPagedFormExample.php',
+ 'PhabricatorPasswordAuthProvider' => 'applications/auth/provider/PhabricatorPasswordAuthProvider.php',
'PhabricatorPasswordHasher' => 'infrastructure/util/password/PhabricatorPasswordHasher.php',
'PhabricatorPasswordHasherTestCase' => 'infrastructure/util/password/__tests__/PhabricatorPasswordHasherTestCase.php',
'PhabricatorPasswordHasherUnavailableException' => 'infrastructure/util/password/PhabricatorPasswordHasherUnavailableException.php',
@@ -1936,6 +1932,7 @@
'PhabricatorPeopleSearchEngine' => 'applications/people/query/PhabricatorPeopleSearchEngine.php',
'PhabricatorPeopleTestDataGenerator' => 'applications/people/lipsum/PhabricatorPeopleTestDataGenerator.php',
'PhabricatorPeopleWelcomeController' => 'applications/people/controller/PhabricatorPeopleWelcomeController.php',
+ 'PhabricatorPersonaAuthProvider' => 'applications/auth/provider/PhabricatorPersonaAuthProvider.php',
'PhabricatorPhameConfigOptions' => 'applications/phame/config/PhabricatorPhameConfigOptions.php',
'PhabricatorPhamePHIDTypeBlog' => 'applications/phame/phid/PhabricatorPhamePHIDTypeBlog.php',
'PhabricatorPhamePHIDTypePost' => 'applications/phame/phid/PhabricatorPhamePHIDTypePost.php',
@@ -2332,6 +2329,8 @@
'PhabricatorTranslation' => 'infrastructure/internationalization/translation/PhabricatorTranslation.php',
'PhabricatorTranslationsConfigOptions' => 'applications/config/option/PhabricatorTranslationsConfigOptions.php',
'PhabricatorTrivialTestCase' => 'infrastructure/testing/__tests__/PhabricatorTrivialTestCase.php',
+ 'PhabricatorTwitchAuthProvider' => 'applications/auth/provider/PhabricatorTwitchAuthProvider.php',
+ 'PhabricatorTwitterAuthProvider' => 'applications/auth/provider/PhabricatorTwitterAuthProvider.php',
'PhabricatorTwoColumnExample' => 'applications/uiexample/examples/PhabricatorTwoColumnExample.php',
'PhabricatorTypeaheadCompositeDatasource' => 'applications/typeahead/datasource/PhabricatorTypeaheadCompositeDatasource.php',
'PhabricatorTypeaheadDatasource' => 'applications/typeahead/datasource/PhabricatorTypeaheadDatasource.php',
@@ -2379,6 +2378,7 @@
'PhabricatorUserTitleField' => 'applications/people/customfield/PhabricatorUserTitleField.php',
'PhabricatorUserTransaction' => 'applications/people/storage/PhabricatorUserTransaction.php',
'PhabricatorVCSResponse' => 'applications/repository/response/PhabricatorVCSResponse.php',
+ 'PhabricatorWordPressAuthProvider' => 'applications/auth/provider/PhabricatorWordPressAuthProvider.php',
'PhabricatorWorker' => 'infrastructure/daemon/workers/PhabricatorWorker.php',
'PhabricatorWorkerActiveTask' => 'infrastructure/daemon/workers/storage/PhabricatorWorkerActiveTask.php',
'PhabricatorWorkerArchiveTask' => 'infrastructure/daemon/workers/storage/PhabricatorWorkerArchiveTask.php',
@@ -3905,6 +3905,7 @@
'PhabricatorActionListView' => 'AphrontView',
'PhabricatorActionView' => 'AphrontView',
'PhabricatorAllCapsTranslation' => 'PhabricatorTranslation',
+ 'PhabricatorAmazonAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorAnchorView' => 'AphrontView',
'PhabricatorAphlictManagementBuildWorkflow' => 'PhabricatorAphlictManagementWorkflow',
'PhabricatorAphlictManagementDebugWorkflow' => 'PhabricatorAphlictManagementWorkflow',
@@ -4024,6 +4025,7 @@
'PhabricatorApplicationXHProf' => 'PhabricatorApplication',
'PhabricatorApplicationsController' => 'PhabricatorController',
'PhabricatorApplicationsListController' => 'PhabricatorApplicationsController',
+ 'PhabricatorAsanaAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorAsanaConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorAuditAddCommentController' => 'PhabricatorAuditController',
'PhabricatorAuditComment' => array(
@@ -4081,23 +4083,6 @@
'PhabricatorAuthProviderConfigQuery' => 'PhabricatorCursorPagedPolicyAwareQuery',
'PhabricatorAuthProviderConfigTransaction' => 'PhabricatorApplicationTransaction',
'PhabricatorAuthProviderConfigTransactionQuery' => 'PhabricatorApplicationTransactionQuery',
- 'PhabricatorAuthProviderLDAP' => 'PhabricatorAuthProvider',
- 'PhabricatorAuthProviderOAuth' => 'PhabricatorAuthProvider',
- 'PhabricatorAuthProviderOAuth1' => 'PhabricatorAuthProviderOAuth',
- 'PhabricatorAuthProviderOAuth1Bitbucket' => 'PhabricatorAuthProviderOAuth1',
- 'PhabricatorAuthProviderOAuth1JIRA' => 'PhabricatorAuthProviderOAuth1',
- 'PhabricatorAuthProviderOAuth1Twitter' => 'PhabricatorAuthProviderOAuth1',
- 'PhabricatorAuthProviderOAuth2' => 'PhabricatorAuthProviderOAuth',
- 'PhabricatorAuthProviderOAuthAmazon' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthAsana' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthDisqus' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthFacebook' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthGitHub' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthGoogle' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthTwitch' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderOAuthWordPress' => 'PhabricatorAuthProviderOAuth2',
- 'PhabricatorAuthProviderPassword' => 'PhabricatorAuthProvider',
- 'PhabricatorAuthProviderPersona' => 'PhabricatorAuthProvider',
'PhabricatorAuthRegisterController' => 'PhabricatorAuthController',
'PhabricatorAuthSession' => array(
'PhabricatorAuthDAO',
@@ -4123,6 +4108,7 @@
'PhabricatorBarePageView' => 'AphrontPageView',
'PhabricatorBaseEnglishTranslation' => 'PhabricatorTranslation',
'PhabricatorBcryptPasswordHasher' => 'PhabricatorPasswordHasher',
+ 'PhabricatorBitbucketAuthProvider' => 'PhabricatorOAuth1AuthProvider',
'PhabricatorBot' => 'PhabricatorDaemon',
'PhabricatorBotBaseStreamingProtocolAdapter' => 'PhabricatorBaseProtocolAdapter',
'PhabricatorBotChannel' => 'PhabricatorBotTarget',
@@ -4368,6 +4354,7 @@
'PhabricatorDifferentialRevisionTestDataGenerator' => 'PhabricatorTestDataGenerator',
'PhabricatorDiffusionConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorDisabledUserController' => 'PhabricatorAuthController',
+ 'PhabricatorDisqusAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorDisqusConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorDraft' => 'PhabricatorDraftDAO',
'PhabricatorDraftDAO' => 'PhabricatorLiskDAO',
@@ -4395,6 +4382,7 @@
'PhabricatorPolicyInterface',
),
'PhabricatorExternalAccountQuery' => 'PhabricatorCursorPagedPolicyAwareQuery',
+ 'PhabricatorFacebookAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorFactAggregate' => 'PhabricatorFactDAO',
'PhabricatorFactChartController' => 'PhabricatorFactController',
'PhabricatorFactController' => 'PhabricatorController',
@@ -4505,8 +4493,10 @@
'PhabricatorGarbageCollectorDaemon' => 'PhabricatorDaemon',
'PhabricatorGestureExample' => 'PhabricatorUIExample',
'PhabricatorGitGraphStream' => 'PhabricatorRepositoryGraphStream',
+ 'PhabricatorGitHubAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorGlobalLock' => 'PhutilLock',
'PhabricatorGlobalUploadTargetView' => 'AphrontView',
+ 'PhabricatorGoogleAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorHandleQuery' => 'PhabricatorCursorPagedPolicyAwareQuery',
'PhabricatorHarbormasterConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorHashTestCase' => 'PhabricatorTestCase',
@@ -4529,8 +4519,10 @@
'PhabricatorInternationalizationManagementExtractWorkflow' => 'PhabricatorInternationalizationManagementWorkflow',
'PhabricatorInternationalizationManagementWorkflow' => 'PhabricatorManagementWorkflow',
'PhabricatorIteratedMD5PasswordHasher' => 'PhabricatorPasswordHasher',
+ 'PhabricatorJIRAAuthProvider' => 'PhabricatorOAuth1AuthProvider',
'PhabricatorJavelinLinter' => 'ArcanistLinter',
'PhabricatorKeyValueDatabaseCache' => 'PhutilKeyValueCache',
+ 'PhabricatorLDAPAuthProvider' => 'PhabricatorAuthProvider',
'PhabricatorLegacyEdgeType' => 'PhabricatorEdgeType',
'PhabricatorLegalpadConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorLegalpadPHIDTypeDocument' => 'PhabricatorPHIDType',
@@ -4639,6 +4631,9 @@
'PhabricatorNotificationStatusController' => 'PhabricatorNotificationController',
'PhabricatorNotificationStatusView' => 'AphrontTagView',
'PhabricatorNotificationTestController' => 'PhabricatorNotificationController',
+ 'PhabricatorOAuth1AuthProvider' => 'PhabricatorOAuthAuthProvider',
+ 'PhabricatorOAuth2AuthProvider' => 'PhabricatorOAuthAuthProvider',
+ 'PhabricatorOAuthAuthProvider' => 'PhabricatorAuthProvider',
'PhabricatorOAuthClientAuthorization' => array(
'PhabricatorOAuthServerDAO',
'PhabricatorPolicyInterface',
@@ -4695,6 +4690,7 @@
'PhabricatorPHDConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorPHPMailerConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorPagedFormExample' => 'PhabricatorUIExample',
+ 'PhabricatorPasswordAuthProvider' => 'PhabricatorAuthProvider',
'PhabricatorPasswordHasher' => 'Phobject',
'PhabricatorPasswordHasherTestCase' => 'PhabricatorTestCase',
'PhabricatorPasswordHasherUnavailableException' => 'Exception',
@@ -4747,6 +4743,7 @@
'PhabricatorPeopleSearchEngine' => 'PhabricatorApplicationSearchEngine',
'PhabricatorPeopleTestDataGenerator' => 'PhabricatorTestDataGenerator',
'PhabricatorPeopleWelcomeController' => 'PhabricatorPeopleController',
+ 'PhabricatorPersonaAuthProvider' => 'PhabricatorAuthProvider',
'PhabricatorPhameConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorPhamePHIDTypeBlog' => 'PhabricatorPHIDType',
'PhabricatorPhamePHIDTypePost' => 'PhabricatorPHIDType',
@@ -5174,6 +5171,8 @@
'PhabricatorTransformedFile' => 'PhabricatorFileDAO',
'PhabricatorTranslationsConfigOptions' => 'PhabricatorApplicationConfigOptions',
'PhabricatorTrivialTestCase' => 'PhabricatorTestCase',
+ 'PhabricatorTwitchAuthProvider' => 'PhabricatorOAuth2AuthProvider',
+ 'PhabricatorTwitterAuthProvider' => 'PhabricatorOAuth1AuthProvider',
'PhabricatorTwoColumnExample' => 'PhabricatorUIExample',
'PhabricatorTypeaheadCompositeDatasource' => 'PhabricatorTypeaheadDatasource',
'PhabricatorTypeaheadDatasource' => 'Phobject',
@@ -5231,6 +5230,7 @@
'PhabricatorUserTitleField' => 'PhabricatorUserCustomField',
'PhabricatorUserTransaction' => 'PhabricatorApplicationTransaction',
'PhabricatorVCSResponse' => 'AphrontResponse',
+ 'PhabricatorWordPressAuthProvider' => 'PhabricatorOAuth2AuthProvider',
'PhabricatorWorkerActiveTask' => 'PhabricatorWorkerTask',
'PhabricatorWorkerArchiveTask' => 'PhabricatorWorkerTask',
'PhabricatorWorkerDAO' => 'PhabricatorLiskDAO',
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthAmazon.php b/src/applications/auth/provider/PhabricatorAmazonAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthAmazon.php
rename to src/applications/auth/provider/PhabricatorAmazonAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthAmazon.php
+++ b/src/applications/auth/provider/PhabricatorAmazonAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthAmazon
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorAmazonAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('Amazon');
@@ -36,7 +36,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthAmazon();
+ return new PhutilAmazonAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthAsana.php b/src/applications/auth/provider/PhabricatorAsanaAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthAsana.php
rename to src/applications/auth/provider/PhabricatorAsanaAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthAsana.php
+++ b/src/applications/auth/provider/PhabricatorAsanaAuthProvider.php
@@ -1,7 +1,6 @@
<?php
-final class PhabricatorAuthProviderOAuthAsana
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorAsanaAuthProvider extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('Asana');
@@ -28,7 +27,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthAsana();
+ return new PhutilAsanaAuthAdapter();
}
protected function getLoginIcon() {
@@ -39,7 +38,7 @@
$providers = self::getAllEnabledProviders();
foreach ($providers as $provider) {
- if ($provider instanceof PhabricatorAuthProviderOAuthAsana) {
+ if ($provider instanceof PhabricatorAsanaAuthProvider) {
return $provider;
}
}
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1Bitbucket.php b/src/applications/auth/provider/PhabricatorBitbucketAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuth1Bitbucket.php
rename to src/applications/auth/provider/PhabricatorBitbucketAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1Bitbucket.php
+++ b/src/applications/auth/provider/PhabricatorBitbucketAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuth1Bitbucket
- extends PhabricatorAuthProviderOAuth1 {
+final class PhabricatorBitbucketAuthProvider
+ extends PhabricatorOAuth1AuthProvider {
public function getProviderName() {
return pht('Bitbucket');
@@ -17,7 +17,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthBitbucket();
+ return new PhutilBitbucketAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthDisqus.php b/src/applications/auth/provider/PhabricatorDisqusAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthDisqus.php
rename to src/applications/auth/provider/PhabricatorDisqusAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthDisqus.php
+++ b/src/applications/auth/provider/PhabricatorDisqusAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthDisqus
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorDisqusAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('Disqus');
@@ -26,7 +26,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthDisqus();
+ return new PhutilDisqusAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthFacebook.php b/src/applications/auth/provider/PhabricatorFacebookAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthFacebook.php
rename to src/applications/auth/provider/PhabricatorFacebookAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthFacebook.php
+++ b/src/applications/auth/provider/PhabricatorFacebookAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthFacebook
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorFacebookAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
const KEY_REQUIRE_SECURE = 'oauth:facebook:require-secure';
@@ -39,7 +39,7 @@
$require_secure = $this->getProviderConfig()->getProperty(
self::KEY_REQUIRE_SECURE);
- return id(new PhutilAuthAdapterOAuthFacebook())
+ return id(new PhutilFacebookAuthAdapter())
->setRequireSecureBrowsing($require_secure);
}
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthGitHub.php b/src/applications/auth/provider/PhabricatorGitHubAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthGitHub.php
rename to src/applications/auth/provider/PhabricatorGitHubAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthGitHub.php
+++ b/src/applications/auth/provider/PhabricatorGitHubAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthGitHub
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorGitHubAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('GitHub');
@@ -29,7 +29,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthGitHub();
+ return new PhutilGitHubAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthGoogle.php b/src/applications/auth/provider/PhabricatorGoogleAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthGoogle.php
rename to src/applications/auth/provider/PhabricatorGoogleAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthGoogle.php
+++ b/src/applications/auth/provider/PhabricatorGoogleAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthGoogle
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorGoogleAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('Google');
@@ -33,7 +33,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthGoogle();
+ return new PhutilGoogleAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1JIRA.php b/src/applications/auth/provider/PhabricatorJIRAAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuth1JIRA.php
rename to src/applications/auth/provider/PhabricatorJIRAAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1JIRA.php
+++ b/src/applications/auth/provider/PhabricatorJIRAAuthProvider.php
@@ -1,7 +1,6 @@
<?php
-final class PhabricatorAuthProviderOAuth1JIRA
- extends PhabricatorAuthProviderOAuth1 {
+final class PhabricatorJIRAAuthProvider extends PhabricatorOAuth1AuthProvider {
public function getJIRABaseURI() {
return $this->getProviderConfig()->getProperty(self::PROPERTY_JIRA_URI);
@@ -58,7 +57,7 @@
protected function newOAuthAdapter() {
$config = $this->getProviderConfig();
- return id(new PhutilAuthAdapterOAuthJIRA())
+ return id(new PhutilJIRAAuthAdapter())
->setAdapterDomain($config->getProviderDomain())
->setJIRABaseURI($config->getProperty(self::PROPERTY_JIRA_URI))
->setPrivateKey(
@@ -143,7 +142,7 @@
$config->setProviderDomain($values[$key_name]);
$consumer_key = 'phjira.'.Filesystem::readRandomCharacters(16);
- list($public, $private) = PhutilAuthAdapterOAuthJIRA::newJIRAKeypair();
+ list($public, $private) = PhutilJIRAAuthAdapter::newJIRAKeypair();
$config->setProperty(self::PROPERTY_PUBLIC_KEY, $public);
$config->setProperty(self::PROPERTY_PRIVATE_KEY, $private);
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1.php b/src/applications/auth/provider/PhabricatorOAuth1AuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuth1.php
rename to src/applications/auth/provider/PhabricatorOAuth1AuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1.php
+++ b/src/applications/auth/provider/PhabricatorOAuth1AuthProvider.php
@@ -1,7 +1,7 @@
<?php
-abstract class PhabricatorAuthProviderOAuth1
- extends PhabricatorAuthProviderOAuth {
+abstract class PhabricatorOAuth1AuthProvider
+ extends PhabricatorOAuthAuthProvider {
protected $adapter;
@@ -19,7 +19,7 @@
return self::PROPERTY_CONSUMER_SECRET;
}
- protected function configureAdapter(PhutilAuthAdapterOAuth1 $adapter) {
+ protected function configureAdapter(PhutilOAuth1AuthAdapter $adapter) {
$config = $this->getProviderConfig();
$adapter->setConsumerKey($config->getProperty(self::PROPERTY_CONSUMER_KEY));
$secret = $config->getProperty(self::PROPERTY_CONSUMER_SECRET);
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuth2.php b/src/applications/auth/provider/PhabricatorOAuth2AuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuth2.php
rename to src/applications/auth/provider/PhabricatorOAuth2AuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuth2.php
+++ b/src/applications/auth/provider/PhabricatorOAuth2AuthProvider.php
@@ -1,7 +1,7 @@
<?php
-abstract class PhabricatorAuthProviderOAuth2
- extends PhabricatorAuthProviderOAuth {
+abstract class PhabricatorOAuth2AuthProvider
+ extends PhabricatorOAuthAuthProvider {
const PROPERTY_APP_ID = 'oauth:app:id';
const PROPERTY_APP_SECRET = 'oauth:app:secret';
@@ -15,7 +15,7 @@
}
- protected function configureAdapter(PhutilAuthAdapterOAuth $adapter) {
+ protected function configureAdapter(PhutilOAuthAuthAdapter $adapter) {
$config = $this->getProviderConfig();
$adapter->setClientID($config->getProperty(self::PROPERTY_APP_ID));
$adapter->setClientSecret(
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuth.php b/src/applications/auth/provider/PhabricatorOAuthAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuth.php
rename to src/applications/auth/provider/PhabricatorOAuthAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuth.php
+++ b/src/applications/auth/provider/PhabricatorOAuthAuthProvider.php
@@ -1,6 +1,6 @@
<?php
-abstract class PhabricatorAuthProviderOAuth extends PhabricatorAuthProvider {
+abstract class PhabricatorOAuthAuthProvider extends PhabricatorAuthProvider {
const PROPERTY_NOTE = 'oauth:app:note';
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderPassword.php b/src/applications/auth/provider/PhabricatorPasswordAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderPassword.php
rename to src/applications/auth/provider/PhabricatorPasswordAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderPassword.php
+++ b/src/applications/auth/provider/PhabricatorPasswordAuthProvider.php
@@ -1,7 +1,6 @@
<?php
-final class PhabricatorAuthProviderPassword
- extends PhabricatorAuthProvider {
+final class PhabricatorPasswordAuthProvider extends PhabricatorAuthProvider {
private $adapter;
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderPersona.php b/src/applications/auth/provider/PhabricatorPersonaAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderPersona.php
rename to src/applications/auth/provider/PhabricatorPersonaAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderPersona.php
+++ b/src/applications/auth/provider/PhabricatorPersonaAuthProvider.php
@@ -1,7 +1,6 @@
<?php
-final class PhabricatorAuthProviderPersona
- extends PhabricatorAuthProvider {
+final class PhabricatorPersonaAuthProvider extends PhabricatorAuthProvider {
private $adapter;
@@ -16,7 +15,7 @@
public function getAdapter() {
if (!$this->adapter) {
- $adapter = new PhutilAuthAdapterPersona();
+ $adapter = new PhutilPersonaAuthAdapter();
$this->adapter = $adapter;
}
return $this->adapter;
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthTwitch.php b/src/applications/auth/provider/PhabricatorTwitchAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthTwitch.php
rename to src/applications/auth/provider/PhabricatorTwitchAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthTwitch.php
+++ b/src/applications/auth/provider/PhabricatorTwitchAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthTwitch
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorTwitchAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('Twitch.tv');
@@ -26,7 +26,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthTwitch();
+ return new PhutilTwitchAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1Twitter.php b/src/applications/auth/provider/PhabricatorTwitterAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuth1Twitter.php
rename to src/applications/auth/provider/PhabricatorTwitterAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuth1Twitter.php
+++ b/src/applications/auth/provider/PhabricatorTwitterAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuth1Twitter
- extends PhabricatorAuthProviderOAuth1 {
+final class PhabricatorTwitterAuthProvider
+ extends PhabricatorOAuth1AuthProvider {
public function getProviderName() {
return pht('Twitter');
@@ -25,7 +25,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthTwitter();
+ return new PhutilTwitterAuthAdapter();
}
protected function getLoginIcon() {
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderOAuthWordPress.php b/src/applications/auth/provider/PhabricatorWordPressAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderOAuthWordPress.php
rename to src/applications/auth/provider/PhabricatorWordPressAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderOAuthWordPress.php
+++ b/src/applications/auth/provider/PhabricatorWordPressAuthProvider.php
@@ -1,7 +1,7 @@
<?php
-final class PhabricatorAuthProviderOAuthWordPress
- extends PhabricatorAuthProviderOAuth2 {
+final class PhabricatorWordPressAuthProvider
+ extends PhabricatorOAuth2AuthProvider {
public function getProviderName() {
return pht('WordPress.com');
@@ -29,7 +29,7 @@
}
protected function newOAuthAdapter() {
- return new PhutilAuthAdapterOAuthWordPress();
+ return new PhutilWordPressAuthAdapter();
}
protected function getLoginIcon() {

File Metadata

Mime Type
text/plain
Expires
Mon, May 20, 2:50 AM (3 w, 6 d ago)
Storage Engine
amazon-s3
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
phabricator/secure/n7/en/crxviia2ielvxb32
Default Alt Text
D9999.diff (37 KB)

Event Timeline
diff --git a/src/applications/auth/provider/PhabricatorAuthProviderLDAP.php b/src/applications/auth/provider/PhabricatorLDAPAuthProvider.php
rename from src/applications/auth/provider/PhabricatorAuthProviderLDAP.php
rename to src/applications/auth/provider/PhabricatorLDAPAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProviderLDAP.php
+++ b/src/applications/auth/provider/PhabricatorLDAPAuthProvider.php
@@ -1,7 +1,6 @@
<?php
-final class PhabricatorAuthProviderLDAP
- extends PhabricatorAuthProvider {
+final class PhabricatorLDAPAuthProvider extends PhabricatorAuthProvider {
private $adapter;
@@ -34,7 +33,7 @@
$search_attributes = phutil_split_lines($search_attributes, false);
$search_attributes = array_filter($search_attributes);
- $adapter = id(new PhutilAuthAdapterLDAP())
+ $adapter = id(new PhutilLDAPAuthAdapter())
->setHostname(
$conf->getProperty(self::KEY_HOSTNAME))
->setPort(
@@ -160,7 +159,7 @@
$adapter->setLoginPassword($password);
// TODO: This calls ldap_bind() eventually, which dumps cleartext
// passwords to the error log. See note in PhutilAuthAdapterLDAP.
// See T3351.
DarkConsoleErrorLogPluginAPI::enableDiscardMode();
@@ -160,7 +159,7 @@
$adapter->setLoginPassword($password);
// TODO: This calls ldap_bind() eventually, which dumps cleartext
- // passwords to the error log. See note in PhutilAuthAdapterLDAP.
+ // passwords to the error log. See note in PhutilLDAPAuthAdapter.
// See T3351.
DarkConsoleErrorLogPluginAPI::enableDiscardMode();